@@ -83,15 +83,6 @@ class TestParagraphs(ParserTestCase):
 class TestHeadings(ParserTestCase):
     """ Test various heading problems """
 
-    def class_setup(self):
-        """ Require show_section_numbers = 0 to workaround counter
-        global state saved in request.
-        """
-        self.config = self.TestConfig(show_section_numbers=0)
-
-    def class_teardown(self):
-        del self.config
-
     def testIgnoreWhiteSpaceAroundHeadingText(self):
         """ parser.wiki: ignore white space around heading text
 
@@ -112,15 +103,6 @@ class TestHeadings(ParserTestCase):
 
 class TestTOC(ParserTestCase):
 
-    def class_setup(self):
-        """ Require show_section_numbers = 0 to workaround counter
-        global state saved in request.
-        """
-        self.config = self.TestConfig(show_section_numbers=0)
-
-    def class_teardown(self):
-        del self.config
-
     def testHeadingWithWhiteSpace(self):
         """ parser.wiki: TOC links to headings with white space
 
